<?php

namespace Litecms\Vendor\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Litecms\Vendor\Http\Requests\VendorUserRequest;
use Litecms\Vendor\Interfaces\VendorRepositoryInterface;
use Response;
use User;

class VendorUserController extends UserController
{
    /**
     * Initialize vendor controller.
     *
     * @param type VendorRepositoryInterface $vendor
     *
     * @return type
     */
    public function __construct(VendorRepositoryInterface $vendor)
    {
        $this->model = $vendor;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(VendorUserRequest $request)
    {
        $vendors = $this->model->all();

        $this->theme->prependTitle(trans('vendor::vendor.names').' :: ');

        return $this->theme->of('vendor::user.vendor.index', compact('vendors'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(VendorUserRequest $request, $role, $id)
    {
        $vendor = $this->model->find($id);

        return $this->theme->of('vendor::user.vendor.show', compact('vendor'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(VendorUserRequest $request)
    {
        $vendor = $this->model->findOrNew(0);

        Former::populate($vendor);

        return $this->theme->of('vendor::user.vendor.create', compact('vendor'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(VendorUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $vendor = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('vendor::vendor.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(VendorUserRequest $request, $role, $id)
    {
        $vendor = $this->model->find($id);

        Former::populate($vendor);

        return $this->theme->of('vendor::user.vendor.edit', compact('vendor'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(VendorUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $vendor = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('vendor::vendor.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(VendorUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('vendor::vendor.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
